Documentation
¶
Index ¶
Constants ¶
const ( DisplayDenom = "tac" BaseDenom = "utac" BaseDenomUnit = 18 // EVMCoinName is the full name of the native EVM coin. EVMCoinName = "TAC" // EVMCoinSymbol is the ticker symbol of the native EVM coin. EVMCoinSymbol = "TAC" // EVMCoinDescription is the description stored in bank denom metadata. EVMCoinDescription = "Native 18-decimal denom metadata for TacChain EVM" // Bech32PrefixAccAddr defines the Bech32 prefix of an account's address. Bech32PrefixAccAddr = "tac" NodeDir = ".tacchaind" AppName = "TacChainApp" DefaultChainID = "tacchain_2391337-1" // TimeoutCommit defines the default consensus commit timeout. TimeoutCommit = 1 * time.Second )
Variables ¶
var ( // Bech32PrefixAccPub defines the Bech32 prefix of an account's public key. Bech32PrefixAccPub = Bech32PrefixAccAddr + "pub" // Bech32PrefixValAddr defines the Bech32 prefix of a validator's operator address. Bech32PrefixValAddr = Bech32PrefixAccAddr + "valoper" // Bech32PrefixValPub defines the Bech32 prefix of a validator's operator public key. Bech32PrefixValPub = Bech32PrefixAccAddr + "valoperpub" // Bech32PrefixConsAddr defines the Bech32 prefix of a consensus node address. Bech32PrefixConsAddr = Bech32PrefixAccAddr + "valcons" // Bech32PrefixConsPub defines the Bech32 prefix of a consensus node public key. Bech32PrefixConsPub = Bech32PrefixAccAddr + "valconspub" DefaultNodeHome = os.ExpandEnv("$HOME/") + NodeDir // PowerReduction defines the default power reduction value for staking. PowerReduction = sdkmath.NewIntFromBigInt(new(big.Int).Exp(big.NewInt(10), big.NewInt(BaseDenomUnit), nil)) )
Functions ¶
func DefaultBankDenomMetadata ¶
DefaultBankDenomMetadata returns the bank denom metadata for the native EVM coin. This metadata is required by the EVM module's InitEvmCoinInfo to locate the coin denom.
func DefaultBankDenomMetadataFor ¶
DefaultBankDenomMetadataFor returns default metadata for the provided base denom.
func DefaultNativeDenomMetadata ¶
DefaultNativeDenomMetadata returns the bank denom metadata for the native EVM coin. This metadata is required by the EVM module's InitEvmCoinInfo to locate the coin denom.
func SetupSDKConfig ¶
func SetupSDKConfig()
SetupSDKConfig configures the Cosmos SDK globals required by TacChain.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.